@@ -1,10 +1,20 @@
 import math
-from typing import List, Tuple, Union
+from typing import (
+    List,
+    Tuple,
+    Union,
+)
 
 import requests
 import slack
 import woodchips
-from github import Issue, NamedUser, PaginatedList, PullRequest
+from github import (
+    Issue,
+    NamedUser,
+    PullRequest,
+    Team,
+)
+
 
 LOGGER_NAME = 'pullbug'
 
@@ -67,10 +77,11 @@ class Message:
     @staticmethod
     def prepare_pulls_message(
         pull_request: PullRequest.PullRequest,
-        reviewers: PaginatedList.PaginatedList,
+        reviewers: List[Union[NamedUser.NamedUser, Team.Team]],
         users_who_approved: List[NamedUser.NamedUser],
         users_who_requested_changes: List[NamedUser.NamedUser],
         users_who_were_dismissed: List[NamedUser.NamedUser],
+        disable_descriptions: bool = False,
     ) -> Tuple[str, str]:
         """Prepares a GitHub pull request message with a single pull request's data.
         This will then be appended to an array of messages.
@@ -78,11 +89,15 @@ class Message:
         Slack and Discord each have slightly different formatting required, both messages are returned here.
         """
         pull_request_body = pull_request.body if pull_request.body else ''
-        description = (
-            pull_request_body[:DESCRIPTION_MAX_LENGTH] + DESCRIPTION_CONTINUATION
-            if len(pull_request_body) > DESCRIPTION_MAX_LENGTH
-            else pull_request_body
-        )
+        description_message_element = ''
+
+        if disable_descriptions is False:
+            description = (
+                pull_request_body[:DESCRIPTION_MAX_LENGTH] + DESCRIPTION_CONTINUATION
+                if len(pull_request_body) > DESCRIPTION_MAX_LENGTH
+                else pull_request_body
+            )
+            description_message_element = f"\n*Description:* {description}"
 
         slack_reviewers_string = ''
         discord_reviewers_string = ''
@@ -130,8 +145,12 @@ class Message:
             discord_reviewers = []
 
             for reviewer in reviewers:
-                slack_reviewers.append(Message._create_slack_user_link(reviewer))
-                discord_reviewers.append(Message._create_discord_user_link(reviewer))
+                if isinstance(reviewer, NamedUser.NamedUser):
+                    slack_reviewers.append(Message._create_slack_user_link(reviewer))
+                    discord_reviewers.append(Message._create_discord_user_link(reviewer))
+                elif isinstance(reviewer, Team.Team):
+                    slack_reviewers.append(Message._create_slack_team_link(reviewer))
+                    discord_reviewers.append(Message._create_discord_team_link(reviewer))
 
             if slack_reviewers:
                 slack_reviewers_string += f"  :timer_clock: {', '.join(set(slack_reviewers))};"
@@ -141,7 +160,7 @@ class Message:
             f"\n:arrow_heading_up: *Pull Request:* {Message._create_slack_object_link(pull_request)}"
             f"\n*Repo:* <{pull_request.base.repo.html_url}|{pull_request.base.repo.name}>"
             f"\n*Author:* <{pull_request.user.html_url}|{pull_request.user.login}>"
-            f"\n*Description:* {description}"
+            f"{description_message_element}"
             f"\n*Reviewers:*{slack_reviewers_string if slack_reviewers_string else ' NA'}\n"
         )
 
@@ -149,25 +168,29 @@ class Message:
             f"\n:arrow_heading_up: **Pull Request:** {Message._create_discord_object_link(pull_request)}"
             f"\n**Repo:** {pull_request.base.repo.name} (<{pull_request.base.repo.html_url}>)"
             f"\n**Author:** {pull_request.user.html_url} (<{pull_request.user.login}>)"
-            f"\n**Description:** {description}"
+            f"{description_message_element}"
             f"\n*Reviewers:*{discord_reviewers_string if discord_reviewers_string else ' NA'}\n"
         )
 
         return slack_message, discord_message
 
     @staticmethod
-    def prepare_issues_message(issue: Issue.Issue) -> Tuple[str, str]:
+    def prepare_issues_message(issue: Issue.Issue, disable_descriptions: bool = False) -> Tuple[str, str]:
         """Prepares a GitHub issue message with a single issue's data.
         This will then be appended to an array of messages.
 
         Slack and Discord each have slightly different formatting required, both messages are returned here.
         """
         issue_body = issue.body if issue.body else ''
-        description = (
-            issue_body[:DESCRIPTION_MAX_LENGTH] + DESCRIPTION_CONTINUATION
-            if len(issue_body) > DESCRIPTION_MAX_LENGTH
-            else issue_body
-        )
+        description_message_element = ''
+
+        if disable_descriptions is False:
+            description = (
+                issue_body[:DESCRIPTION_MAX_LENGTH] + DESCRIPTION_CONTINUATION
+                if len(issue_body) > DESCRIPTION_MAX_LENGTH
+                else issue_body
+            )
+            description_message_element = f"\n*Description:* {description}"
 
         if issue.assignees:
             slack_users = []
@@ -182,14 +205,14 @@ class Message:
         slack_message = (
             f"\n:exclamation: *Issue:* {Message._create_slack_object_link(issue)}"
             f"\n*Repo:* <{issue.repository.html_url}|{issue.repository.name}>"
-            f"\n*Description:* {description}"
+            f"{description_message_element}"
             f"\n*Assigned to:* {', '.join(slack_users)}\n"
         )
 
         discord_message = (
             f"\n:exclamation: **Issue:** {Message._create_discord_object_link(issue)}"
             f"\n**Repo:** {issue.repository.name} (<{issue.repository.html_url}>)"
-            f"\n**Description:** {description}"
+            f"{description_message_element}"
             f"\n**Assigned to:** {', '.join(discord_users)}\n"
         )
 
@@ -214,3 +237,15 @@ class Message:
     def _create_discord_object_link(object: Union[PullRequest.PullRequest, Issue.Issue]) -> str:
         """Creates a Discord object name/url combo to be used in messages."""
         return f'{object.title} (<{object.html_url}>)'
+
+    @staticmethod
+    def _create_slack_team_link(team: Team.Team) -> str:
+        """Creates a Slack team name/url combo to be used in messages."""
+        # TODO: The URL is not populating currently from PyGithub
+        return team.name
+
+    @staticmethod
+    def _create_discord_team_link(team: Team.Team) -> str:
+        """Creates a Discord team name/url combo to be used in messages."""
+        # TODO: The URL is not populating currently from PyGithub
+        return team.name
